From f29b89d8ac7fcca1cf74462dcc33da24551c924f Mon Sep 17 00:00:00 2001
From: Andreas Sturmlechner <asturm@gentoo.org>
Date: Tue, 31 Aug 2021 16:48:42 +0200
Subject: [PATCH] Make WITH_KWALLET and WITH_KJS proper cmake options

Since I was asked to implement this, might as well make it real options,
not just limited to ANDROID. Even though optional find_package() call is
already being used for KF5Purpose as well.

KF5DocTools is not made required more often than not.

See also: https://invent.kde.org/graphics/okular/-/issues/61
Downstream report: https://bugs.gentoo.org/810958

Signed-off-by: Andreas Sturmlechner <asturm@gentoo.org>
---
 CMakeLists.txt        | 21 ++++++++-------------
 config-okular.h.cmake |  6 ++++++
 core/generator.cpp    |  1 +
 core/scripter.cpp     |  1 +
 4 files changed, 16 insertions(+), 13 deletions(-)

diff --git a/CMakeLists.txt b/CMakeLists.txt
index 547671f24..f1e14fa8b 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -91,12 +91,9 @@ ecm_setup_qtplugin_macro_names(
         PACKAGE_SETUP_AUTOMOC_VARIABLES
 )
 
-set(optionalComponents)
-if (ANDROID)
-#   we want to make sure that generally all components are found
-
-    set(optionalComponents "OPTIONAL_COMPONENTS")
-endif()
+# we want to make sure that generally all components are found
+option(WITH_KWALLET "Build with desktop-wide storage for password support" ON)
+option(WITH_KJS "Build with scripting support" ON)
 
 find_package(KF5 ${KF5_REQUIRED_VERSION} REQUIRED COMPONENTS
     Archive
@@ -110,21 +107,19 @@ find_package(KF5 ${KF5_REQUIRED_VERSION} REQUIRED COMPONENTS
     KIO
     ThreadWeaver
     WindowSystem
-    ${optionalComponents}
+    OPTIONAL_COMPONENTS
     DocTools
-    JS
-    Wallet
 )
 
 if (BUILD_DESKTOP)
     find_package(KF5 ${KF5_REQUIRED_VERSION} REQUIRED COMPONENTS Parts Crash IconThemes TextWidgets)
 endif()
 
-if(KF5Wallet_FOUND)
-    add_definitions(-DWITH_KWALLET=1)
+if(WITH_KWALLET)
+    find_package(KF5Wallet ${KF5_REQUIRED_VERSION} REQUIRED)
 endif()
-if(KF5JS_FOUND)
-    add_definitions(-DWITH_KJS=1)
+if(WITH_KJS)
+    find_package(KF5JS ${KF5_REQUIRED_VERSION} REQUIRED)
 endif()
 
 if(NOT WIN32 AND NOT ANDROID)
diff --git a/config-okular.h.cmake b/config-okular.h.cmake
index 905aac9cb..00e45f77c 100644
--- a/config-okular.h.cmake
+++ b/config-okular.h.cmake
@@ -1,6 +1,12 @@
 /* Defines if force the use DRM in okular */
 #define OKULAR_FORCE_DRM ${_OKULAR_FORCE_DRM}
 
+/* Defines if the KJS framework is available */
+#cmakedefine WITH_KJS
+
+/* Defines if the kwallet framework is available */
+#cmakedefine WITH_KWALLET
+
 /* Defines if the purpose framework is available */
 #define PURPOSE_FOUND ${PURPOSE_FOUND}
 
diff --git a/core/generator.cpp b/core/generator.cpp
index 8360bb32b..0871c17ee 100644
--- a/core/generator.cpp
+++ b/core/generator.cpp
@@ -9,6 +9,7 @@
 */
 
 #include "generator.h"
+#include "config-okular.h"
 #include "generator_p.h"
 #include "observer.h"
 
diff --git a/core/scripter.cpp b/core/scripter.cpp
index c60645895..2e6eacc72 100644
--- a/core/scripter.cpp
+++ b/core/scripter.cpp
@@ -5,6 +5,7 @@
 */
 
 #include "scripter.h"
+#include "config-okular.h"
 
 #include <QDebug>
 #include <QFile>
-- 
2.35.1

